==> flutter_reaction_button-2.0.1%2B2.tar.gz: CHANGELOG.md <==
## 2.0.1+2

* Minor bugs fixed. Thanks to [Kyle Venn](https://github.com/kvenn)

## 2.0.1+1

* Minor bugs fix
* Code improvements, Thanks to [Felix Gabler](https://github.com/felixgabler)

## 2.0.1

* Add ReactionContainer
* Bugs fix and code improvements, Thanks to [Felix Gabler](https://github.com/felixgabler)

## 2.0.0+3

* Upgrade flutter version

## 2.0.0+2

* Fix Offscreen Issue. Thanks to [rlee1990](https://github.com/rlee1990)

## 2.0.0+1

* Dragging improvement

## 2.0.0

* Change `FlutterReactionButton` to `ReactionButton`
* Change `FlutterReactionButtonCheck` to `ReactionButtonToggle`
* Change `Function(Reaction, int, bool) onReactionChanged` to `Function(T?, bool) onReactionChanged`
* Change `Function(Reaction, int) onReactionChanged` to `Function(T?) onReactionChanged`
* Dynamic scale depending on the hover position
* Dynamic horizontal alignment
* Scrollable position
* Minor bugs fixed

## 1.0.8

* Added support null safety

## 1.0.7+3

* Deprecated Reaction id

## 1.0.7+2

* Improvement box flow

## 1.0.7

* Remove reaction id
* Clean code

## 1.0.6+2

* Minor bugs fixed

## 1.0.6+1

* Minor bugs fixed

## 1.0.6

* Reaction title

## 1.0.5

* Items spacing
* Box padding

## 1.0.4

* Reactions box alignment

## 1.0.3

* Change state externally

## 1.0.2

* Code improvements

## 1.0.1

* Define reaction by id.
* Alternative to popup menu.
* Enable/disable reaction click.

## 1.0.0

* Add ripple effect.

## 0.1.3

* Selected rection index.

## 0.1.2+1

* Add Example.

## 0.1.2

* From plugin to packages.

## 0.1.1

* Reactions List @required.

## 0.1.0

* Update Description pubspec.yaml.

## 0.0.1

* Describe initial release.

==> flutter_reaction_button-3.0.0%2B2.tar.gz: CHANGELOG.md <==
## 3.0.0+2
* Minor updates

## 3.0.0+1
* Update README

## 3.0.0

- **BREAKING CHANGE**:
    - `FlutterReactionButton` and `FlutterReactionButtonToggle` removed
    - `itemSize` is required in `ReactionButton`
    - `onReactionChanged` callback updated
    - `VerticalPosition` and `HorizontalPosition` removed
- Adds `child` to `ReactionButton`
- Animated `ReactionsBox`

## 2.0.2

* Pipeline setup

## 2.0.1+1

* Minor bugs fixed. Thanks to [Kyle Venn](https://github.com/kvenn)

## 2.0.1

* Adds ReactionContainer
* Bugs fix and code improvements, Thanks to [Felix Gabler](https://github.com/felixgabler)

## 2.0.0+3

* Upgrade flutter version

## 2.0.0+2

* Fix Offscreen Issue. Thanks to [rlee1990](https://github.com/rlee1990)

## 2.0.0+1

* Dragging improvement

## 2.0.0

* Change `FlutterReactionButton` to `ReactionButton`
* Change `FlutterReactionButtonCheck` to `ReactionButtonToggle`
* Change `Function(Reaction, int, bool) onReactionChanged` to `Function(T?, bool) onReactionChanged`
* Change `Function(Reaction, int) onReactionChanged` to `Function(T?) onReactionChanged`
* Dynamic scale depending on the hover position
* Dynamic horizontal alignment
* Scrollable position
* Minor bugs fixed

## 1.0.8

* Added support null safety

## 1.0.7+3

* Deprecated Reaction id

## 1.0.7+2

* Improvement box flow

## 1.0.7

* Remove reaction id
* Clean code

## 1.0.6+2

* Minor bugs fixed

## 1.0.6+1

* Minor bugs fixed

## 1.0.6

* Reaction title

## 1.0.5

* Items spacing
* Box padding

## 1.0.4

* Reactions box alignment

## 1.0.3

* Change state externally

## 1.0.2

* Code improvements

## 1.0.1

* Define reaction by id.
* Alternative to popup menu.
* Enable/disable reaction click.

## 1.0.0

* Adds ripple effect.

## 0.1.3

* Selected rection index.

## 0.1.2+1

* Adds Example.

## 0.1.2

* From plugin to packages.

## 0.1.1

* Reactions List @required.

## 0.1.0

* Update Description pubspec.yaml.

## 0.0.1

* Describe initial release.
